"""
Type annotations for taxsettings service client paginators.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from mypy_boto3_taxsettings.client import TaxSettingsClient
    from mypy_boto3_taxsettings.paginator import (
        ListTaxRegistrationsPaginator,
    )

    session = Session()
    client: TaxSettingsClient = session.client("taxsettings")

    list_tax_registrations_paginator: ListTaxRegistrationsPaginator = client.get_paginator("list_tax_registrations")
    ```
"""

from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListTaxRegistrationsResponseTypeDef, PaginatorConfigTypeDef

__all__ = ("ListTaxRegistrationsPaginator",)

_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(Generic[_ItemTypeDef], PageIterator):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListTaxRegistrationsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Paginator.ListTaxRegistrations)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/paginators/#listtaxregistrationspaginator)
    """

    def paginate(
        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListTaxRegistrationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Paginator.ListTaxRegistrations.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/paginators/#listtaxregistrationspaginator)
        """



"""
Main interface for taxsettings service.

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_taxsettings import (
        Client,
        ListTaxRegistrationsPaginator,
        TaxSettingsClient,
    )

    session = Session()
    client: TaxSettingsClient = session.client("taxsettings")

    list_tax_registrations_paginator: ListTaxRegistrationsPaginator = client.get_paginator("list_tax_registrations")
    ```
"""

from .client import TaxSettingsClient
from .paginator import ListTaxRegistrationsPaginator

Client = TaxSettingsClient

__all__ = ("Client", "ListTaxRegistrationsPaginator", "TaxSettingsClient")



"""
Type annotations for taxsettings service client.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/)

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_taxsettings.client import TaxSettingsClient

    session = Session()
    client: TaxSettingsClient = session.client("taxsettings")
    ```
"""

import sys
from typing import Any, Dict, Mapping, Sequence, Type

from botocore.client import BaseClient, ClientMeta

from .paginator import ListTaxRegistrationsPaginator
from .type_defs import (
    BatchDeleteTaxRegistrationResponseTypeDef,
    BatchPutTaxRegistrationResponseTypeDef,
    DestinationS3LocationTypeDef,
    GetTaxRegistrationDocumentResponseTypeDef,
    GetTaxRegistrationResponseTypeDef,
    ListTaxRegistrationsResponseTypeDef,
    PutTaxRegistrationResponseTypeDef,
    TaxDocumentMetadataTypeDef,
    TaxRegistrationEntryTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = ("TaxSettingsClient",)

class BotocoreClientError(Exception):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str

class Exceptions:
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]

class TaxSettingsClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        TaxSettingsClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.exceptions)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#exceptions)
        """

    def batch_delete_tax_registration(
        self, *, accountIds: Sequence[str]
    ) -> BatchDeleteTaxRegistrationResponseTypeDef:
        """
        Deletes tax registration for multiple accounts in batch.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.batch_delete_tax_registration)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#batch_delete_tax_registration)
        """

    def batch_put_tax_registration(
        self, *, accountIds: Sequence[str], taxRegistrationEntry: TaxRegistrationEntryTypeDef
    ) -> BatchPutTaxRegistrationResponseTypeDef:
        """
        Adds or updates tax registration for multiple accounts in batch.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.batch_put_tax_registration)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#batch_put_tax_registration)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        Check if an operation can be paginated.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.can_paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#can_paginate)
        """

    def close(self) -> None:
        """
        Closes underlying endpoint connections.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.close)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#close)
        """

    def delete_tax_registration(self, *, accountId: str = ...) -> Dict[str, Any]:
        """
        Deletes tax registration for a single account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.delete_tax_registration)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#delete_tax_registration)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        Generate a presigned url given a client, its method, and arguments.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.generate_presigned_url)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#generate_presigned_url)
        """

    def get_tax_registration(self, *, accountId: str = ...) -> GetTaxRegistrationResponseTypeDef:
        """
        Retrieves tax registration for a single account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.get_tax_registration)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#get_tax_registration)
        """

    def get_tax_registration_document(
        self,
        *,
        destinationS3Location: DestinationS3LocationTypeDef,
        taxDocumentMetadata: TaxDocumentMetadataTypeDef,
    ) -> GetTaxRegistrationDocumentResponseTypeDef:
        """
        Downloads your tax documents to the Amazon S3 bucket that you specify in your
        request.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.get_tax_registration_document)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#get_tax_registration_document)
        """

    def list_tax_registrations(
        self, *, maxResults: int = ..., nextToken: str = ...
    ) -> ListTaxRegistrationsResponseTypeDef:
        """
        Retrieves the tax registration of accounts listed in a consolidated billing
        family.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.list_tax_registrations)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#list_tax_registrations)
        """

    def put_tax_registration(
        self, *, taxRegistrationEntry: TaxRegistrationEntryTypeDef, accountId: str = ...
    ) -> PutTaxRegistrationResponseTypeDef:
        """
        Adds or updates tax registration for a single account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.put_tax_registration)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#put_tax_registration)
        """

    def get_paginator(
        self, operation_name: Literal["list_tax_registrations"]
    ) -> ListTaxRegistrationsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#TaxSettings.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/client/#get_paginator)
        """



"""
Type annotations for taxsettings service type definitions.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_taxsettings/type_defs/)

Usage::

    ```python
    from mypy_boto3_taxsettings.type_defs import TaxInheritanceDetailsTypeDef

    data: TaxInheritanceDetailsTypeDef = ...
    ```
"""

import sys
from typing import Dict, List, Sequence

from .literals import (
    AddressRoleTypeType,
    IndustriesType,
    IsraelCustomerTypeType,
    IsraelDealerTypeType,
    MalaysiaServiceTaxCodeType,
    PersonTypeType,
    RegistrationTypeType,
    SaudiArabiaTaxRegistrationNumberTypeType,
    SectorType,
    TaxRegistrationNumberTypeType,
    TaxRegistrationStatusType,
    TaxRegistrationTypeType,
    UkraineTrnTypeType,
)

if sys.version_info >= (3, 12):
    from typing import NotRequired
else:
    from typing_extensions import NotRequired
if sys.version_info >= (3, 12):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "TaxInheritanceDetailsTypeDef",
    "AddressTypeDef",
    "JurisdictionTypeDef",
    "CanadaAdditionalInfoTypeDef",
    "EstoniaAdditionalInfoTypeDef",
    "GeorgiaAdditionalInfoTypeDef",
    "IsraelAdditionalInfoTypeDef",
    "ItalyAdditionalInfoTypeDef",
    "KenyaAdditionalInfoTypeDef",
    "MalaysiaAdditionalInfoTypeDef",
    "PolandAdditionalInfoTypeDef",
    "RomaniaAdditionalInfoTypeDef",
    "SaudiArabiaAdditionalInfoTypeDef",
    "SouthKoreaAdditionalInfoTypeDef",
    "SpainAdditionalInfoTypeDef",
    "TurkeyAdditionalInfoTypeDef",
    "UkraineAdditionalInfoTypeDef",
    "BrazilAdditionalInfoTypeDef",
    "IndiaAdditionalInfoTypeDef",
    "MalaysiaAdditionalInfoOutputTypeDef",
    "BatchDeleteTaxRegistrationErrorTypeDef",
    "BatchDeleteTaxRegistrationRequestRequestTypeDef",
    "ResponseMetadataTypeDef",
    "BatchPutTaxRegistrationErrorTypeDef",
    "DeleteTaxRegistrationRequestRequestTypeDef",
    "DestinationS3LocationTypeDef",
    "TaxDocumentMetadataTypeDef",
    "GetTaxRegistrationRequestRequestTypeDef",
    "PaginatorConfigTypeDef",
    "ListTaxRegistrationsRequestRequestTypeDef",
    "SourceS3LocationTypeDef",
    "AccountMetaDataTypeDef",
    "AdditionalInfoRequestTypeDef",
    "AdditionalInfoResponseTypeDef",
    "BatchDeleteTaxRegistrationResponseTypeDef",
    "GetTaxRegistrationDocumentResponseTypeDef",
    "PutTaxRegistrationResponseTypeDef",
    "BatchPutTaxRegistrationResponseTypeDef",
    "GetTaxRegistrationDocumentRequestRequestTypeDef",
    "ListTaxRegistrationsRequestListTaxRegistrationsPaginateTypeDef",
    "TaxRegistrationDocumentTypeDef",
    "TaxRegistrationTypeDef",
    "TaxRegistrationWithJurisdictionTypeDef",
    "VerificationDetailsTypeDef",
    "GetTaxRegistrationResponseTypeDef",
    "AccountDetailsTypeDef",
    "TaxRegistrationEntryTypeDef",
    "ListTaxRegistrationsResponseTypeDef",
    "BatchPutTaxRegistrationRequestRequestTypeDef",
    "PutTaxRegistrationRequestRequestTypeDef",
)

TaxInheritanceDetailsTypeDef = TypedDict(
    "TaxInheritanceDetailsTypeDef",
    {
        "inheritanceObtainedReason": NotRequired[str],
        "parentEntityId": NotRequired[str],
    },
)
AddressTypeDef = TypedDict(
    "AddressTypeDef",
    {
        "addressLine1": str,
        "city": str,
        "countryCode": str,
        "postalCode": str,
        "addressLine2": NotRequired[str],
        "addressLine3": NotRequired[str],
        "districtOrCounty": NotRequired[str],
        "stateOrRegion": NotRequired[str],
    },
)
JurisdictionTypeDef = TypedDict(
    "JurisdictionTypeDef",
    {
        "countryCode": str,
        "stateOrRegion": NotRequired[str],
    },
)
CanadaAdditionalInfoTypeDef = TypedDict(
    "CanadaAdditionalInfoTypeDef",
    {
        "canadaQuebecSalesTaxNumber": NotRequired[str],
        "canadaRetailSalesTaxNumber": NotRequired[str],
        "isResellerAccount": NotRequired[bool],
        "provincialSalesTaxId": NotRequired[str],
    },
)
EstoniaAdditionalInfoTypeDef = TypedDict(
    "EstoniaAdditionalInfoTypeDef",
    {
        "registryCommercialCode": str,
    },
)
GeorgiaAdditionalInfoTypeDef = TypedDict(
    "GeorgiaAdditionalInfoTypeDef",
    {
        "personType": PersonTypeType,
    },
)
IsraelAdditionalInfoTypeDef = TypedDict(
    "IsraelAdditionalInfoTypeDef",
    {
        "customerType": IsraelCustomerTypeType,
        "dealerType": IsraelDealerTypeType,
    },
)
ItalyAdditionalInfoTypeDef = TypedDict(
    "ItalyAdditionalInfoTypeDef",
    {
        "cigNumber": NotRequired[str],
        "cupNumber": NotRequired[str],
        "sdiAccountId": NotRequired[str],
        "taxCode": NotRequired[str],
    },
)
KenyaAdditionalInfoTypeDef = TypedDict(
    "KenyaAdditionalInfoTypeDef",
    {
        "personType": PersonTypeType,
    },
)
MalaysiaAdditionalInfoTypeDef = TypedDict(
    "MalaysiaAdditionalInfoTypeDef",
    {
        "serviceTaxCodes": Sequence[MalaysiaServiceTaxCodeType],
    },
)
PolandAdditionalInfoTypeDef = TypedDict(
    "PolandAdditionalInfoTypeDef",
    {
        "individualRegistrationNumber": NotRequired[str],
        "isGroupVatEnabled": NotRequired[bool],
    },
)
RomaniaAdditionalInfoTypeDef = TypedDict(
    "RomaniaAdditionalInfoTypeDef",
    {
        "taxRegistrationNumberType": TaxRegistrationNumberTypeType,
    },
)
SaudiArabiaAdditionalInfoTypeDef = TypedDict(
    "SaudiArabiaAdditionalInfoTypeDef",
    {
        "taxRegistrationNumberType": NotRequired[SaudiArabiaTaxRegistrationNumberTypeType],
    },
)
SouthKoreaAdditionalInfoTypeDef = TypedDict(
    "SouthKoreaAdditionalInfoTypeDef",
    {
        "businessRepresentativeName": str,
        "itemOfBusiness": str,
        "lineOfBusiness": str,
    },
)
SpainAdditionalInfoTypeDef = TypedDict(
    "SpainAdditionalInfoTypeDef",
    {
        "registrationType": RegistrationTypeType,
    },
)
TurkeyAdditionalInfoTypeDef = TypedDict(
    "TurkeyAdditionalInfoTypeDef",
    {
        "industries": NotRequired[IndustriesType],
        "kepEmailId": NotRequired[str],
        "secondaryTaxId": NotRequired[str],
        "taxOffice": NotRequired[str],
    },
)
UkraineAdditionalInfoTypeDef = TypedDict(
    "UkraineAdditionalInfoTypeDef",
    {
        "ukraineTrnType": UkraineTrnTypeType,
    },
)
BrazilAdditionalInfoTypeDef = TypedDict(
    "BrazilAdditionalInfoTypeDef",
    {
        "ccmCode": NotRequired[str],
        "legalNatureCode": NotRequired[str],
    },
)
IndiaAdditionalInfoTypeDef = TypedDict(
    "IndiaAdditionalInfoTypeDef",
    {
        "pan": NotRequired[str],
    },
)
MalaysiaAdditionalInfoOutputTypeDef = TypedDict(
    "MalaysiaAdditionalInfoOutputTypeDef",
    {
        "serviceTaxCodes": List[MalaysiaServiceTaxCodeType],
    },
)
BatchDeleteTaxRegistrationErrorTypeDef = TypedDict(
    "BatchDeleteTaxRegistrationErrorTypeDef",
    {
        "accountId": str,
        "message": str,
        "code": NotRequired[str],
    },
)
BatchDeleteTaxRegistrationRequestRequestTypeDef = TypedDict(
    "BatchDeleteTaxRegistrationRequestRequestTypeDef",
    {
        "accountIds": Sequence[str],
    },
)
ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
        "HostId": NotRequired[str],
    },
)
BatchPutTaxRegistrationErrorTypeDef = TypedDict(
    "BatchPutTaxRegistrationErrorTypeDef",
    {
        "accountId": str,
        "message": str,
        "code": NotRequired[str],
    },
)
DeleteTaxRegistrationRequestRequestTypeDef = TypedDict(
    "DeleteTaxRegistrationRequestRequestTypeDef",
    {
        "accountId": NotRequired[str],
    },
)
DestinationS3LocationTypeDef = TypedDict(
    "DestinationS3LocationTypeDef",
    {
        "bucket": str,
        "prefix": NotRequired[str],
    },
)
TaxDocumentMetadataTypeDef = TypedDict(
    "TaxDocumentMetadataTypeDef",
    {
        "taxDocumentAccessToken": str,
        "taxDocumentName": str,
    },
)
GetTaxRegistrationRequestRequestTypeDef = TypedDict(
    "GetTaxRegistrationRequestRequestTypeDef",
    {
        "accountId": NotRequired[str],
    },
)
PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": NotRequired[int],
        "PageSize": NotRequired[int],
        "StartingToken": NotRequired[str],
    },
)
ListTaxRegistrationsRequestRequestTypeDef = TypedDict(
    "ListTaxRegistrationsRequestRequestTypeDef",
    {
        "maxResults": NotRequired[int],
        "nextToken": NotRequired[str],
    },
)
SourceS3LocationTypeDef = TypedDict(
    "SourceS3LocationTypeDef",
    {
        "bucket": str,
        "key": str,
    },
)
AccountMetaDataTypeDef = TypedDict(
    "AccountMetaDataTypeDef",
    {
        "accountName": NotRequired[str],
        "address": NotRequired[AddressTypeDef],
        "addressRoleMap": NotRequired[Dict[AddressRoleTypeType, JurisdictionTypeDef]],
        "addressType": NotRequired[AddressRoleTypeType],
        "seller": NotRequired[str],
    },
)
AdditionalInfoRequestTypeDef = TypedDict(
    "AdditionalInfoRequestTypeDef",
    {
        "canadaAdditionalInfo": NotRequired[CanadaAdditionalInfoTypeDef],
        "estoniaAdditionalInfo": NotRequired[EstoniaAdditionalInfoTypeDef],
        "georgiaAdditionalInfo": NotRequired[GeorgiaAdditionalInfoTypeDef],
        "israelAdditionalInfo": NotRequired[IsraelAdditionalInfoTypeDef],
        "italyAdditionalInfo": NotRequired[ItalyAdditionalInfoTypeDef],
        "kenyaAdditionalInfo": NotRequired[KenyaAdditionalInfoTypeDef],
        "malaysiaAdditionalInfo": NotRequired[MalaysiaAdditionalInfoTypeDef],
        "polandAdditionalInfo": NotRequired[PolandAdditionalInfoTypeDef],
        "romaniaAdditionalInfo": NotRequired[RomaniaAdditionalInfoTypeDef],
        "saudiArabiaAdditionalInfo": NotRequired[SaudiArabiaAdditionalInfoTypeDef],
        "southKoreaAdditionalInfo": NotRequired[SouthKoreaAdditionalInfoTypeDef],
        "spainAdditionalInfo": NotRequired[SpainAdditionalInfoTypeDef],
        "turkeyAdditionalInfo": NotRequired[TurkeyAdditionalInfoTypeDef],
        "ukraineAdditionalInfo": NotRequired[UkraineAdditionalInfoTypeDef],
    },
)
AdditionalInfoResponseTypeDef = TypedDict(
    "AdditionalInfoResponseTypeDef",
    {
        "brazilAdditionalInfo": NotRequired[BrazilAdditionalInfoTypeDef],
        "canadaAdditionalInfo": NotRequired[CanadaAdditionalInfoTypeDef],
        "estoniaAdditionalInfo": NotRequired[EstoniaAdditionalInfoTypeDef],
        "georgiaAdditionalInfo": NotRequired[GeorgiaAdditionalInfoTypeDef],
        "indiaAdditionalInfo": NotRequired[IndiaAdditionalInfoTypeDef],
        "israelAdditionalInfo": NotRequired[IsraelAdditionalInfoTypeDef],
        "italyAdditionalInfo": NotRequired[ItalyAdditionalInfoTypeDef],
        "kenyaAdditionalInfo": NotRequired[KenyaAdditionalInfoTypeDef],
        "malaysiaAdditionalInfo": NotRequired[MalaysiaAdditionalInfoOutputTypeDef],
        "polandAdditionalInfo": NotRequired[PolandAdditionalInfoTypeDef],
        "romaniaAdditionalInfo": NotRequired[RomaniaAdditionalInfoTypeDef],
        "saudiArabiaAdditionalInfo": NotRequired[SaudiArabiaAdditionalInfoTypeDef],
        "southKoreaAdditionalInfo": NotRequired[SouthKoreaAdditionalInfoTypeDef],
        "spainAdditionalInfo": NotRequired[SpainAdditionalInfoTypeDef],
        "turkeyAdditionalInfo": NotRequired[TurkeyAdditionalInfoTypeDef],
        "ukraineAdditionalInfo": NotRequired[UkraineAdditionalInfoTypeDef],
    },
)
BatchDeleteTaxRegistrationResponseTypeDef = TypedDict(
    "BatchDeleteTaxRegistrationResponseTypeDef",
    {
        "errors": List[BatchDeleteTaxRegistrationErrorTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetTaxRegistrationDocumentResponseTypeDef = TypedDict(
    "GetTaxRegistrationDocumentResponseTypeDef",
    {
        "destinationFilePath": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
PutTaxRegistrationResponseTypeDef = TypedDict(
    "PutTaxRegistrationResponseTypeDef",
    {
        "status": TaxRegistrationStatusType,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
BatchPutTaxRegistrationResponseTypeDef = TypedDict(
    "BatchPutTaxRegistrationResponseTypeDef",
    {
        "errors": List[BatchPutTaxRegistrationErrorTypeDef],
        "status": TaxRegistrationStatusType,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetTaxRegistrationDocumentRequestRequestTypeDef = TypedDict(
    "GetTaxRegistrationDocumentRequestRequestTypeDef",
    {
        "destinationS3Location": DestinationS3LocationTypeDef,
        "taxDocumentMetadata": TaxDocumentMetadataTypeDef,
    },
)
ListTaxRegistrationsRequestListTaxRegistrationsPaginateTypeDef = TypedDict(
    "ListTaxRegistrationsRequestListTaxRegistrationsPaginateTypeDef",
    {
        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
    },
)
TaxRegistrationDocumentTypeDef = TypedDict(
    "TaxRegistrationDocumentTypeDef",
    {
        "s3Location": SourceS3LocationTypeDef,
    },
)
TaxRegistrationTypeDef = TypedDict(
    "TaxRegistrationTypeDef",
    {
        "legalAddress": AddressTypeDef,
        "legalName": str,
        "registrationId": str,
        "registrationType": TaxRegistrationTypeType,
        "status": TaxRegistrationStatusType,
        "additionalTaxInformation": NotRequired[AdditionalInfoResponseTypeDef],
        "certifiedEmailId": NotRequired[str],
        "sector": NotRequired[SectorType],
        "taxDocumentMetadatas": NotRequired[List[TaxDocumentMetadataTypeDef]],
    },
)
TaxRegistrationWithJurisdictionTypeDef = TypedDict(
    "TaxRegistrationWithJurisdictionTypeDef",
    {
        "jurisdiction": JurisdictionTypeDef,
        "legalName": str,
        "registrationId": str,
        "registrationType": TaxRegistrationTypeType,
        "status": TaxRegistrationStatusType,
        "additionalTaxInformation": NotRequired[AdditionalInfoResponseTypeDef],
        "certifiedEmailId": NotRequired[str],
        "sector": NotRequired[SectorType],
        "taxDocumentMetadatas": NotRequired[List[TaxDocumentMetadataTypeDef]],
    },
)
VerificationDetailsTypeDef = TypedDict(
    "VerificationDetailsTypeDef",
    {
        "dateOfBirth": NotRequired[str],
        "taxRegistrationDocuments": NotRequired[Sequence[TaxRegistrationDocumentTypeDef]],
    },
)
GetTaxRegistrationResponseTypeDef = TypedDict(
    "GetTaxRegistrationResponseTypeDef",
    {
        "taxRegistration": TaxRegistrationTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
AccountDetailsTypeDef = TypedDict(
    "AccountDetailsTypeDef",
    {
        "accountId": NotRequired[str],
        "accountMetaData": NotRequired[AccountMetaDataTypeDef],
        "taxInheritanceDetails": NotRequired[TaxInheritanceDetailsTypeDef],
        "taxRegistration": NotRequired[TaxRegistrationWithJurisdictionTypeDef],
    },
)
TaxRegistrationEntryTypeDef = TypedDict(
    "TaxRegistrationEntryTypeDef",
    {
        "registrationId": str,
        "registrationType": TaxRegistrationTypeType,
        "additionalTaxInformation": NotRequired[AdditionalInfoRequestTypeDef],
        "certifiedEmailId": NotRequired[str],
        "legalAddress": NotRequired[AddressTypeDef],
        "legalName": NotRequired[str],
        "sector": NotRequired[SectorType],
        "verificationDetails": NotRequired[VerificationDetailsTypeDef],
    },
)
ListTaxRegistrationsResponseTypeDef = TypedDict(
    "ListTaxRegistrationsResponseTypeDef",
    {
        "accountDetails": List[AccountDetailsTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
BatchPutTaxRegistrationRequestRequestTypeDef = TypedDict(
    "BatchPutTaxRegistrationRequestRequestTypeDef",
    {
        "accountIds": Sequence[str],
        "taxRegistrationEntry": TaxRegistrationEntryTypeDef,
    },
)
PutTaxRegistrationRequestRequestTypeDef = TypedDict(
    "PutTaxRegistrationRequestRequestTypeDef",
    {
        "taxRegistrationEntry": TaxRegistrationEntryTypeDef,
        "accountId": NotRequired[str],
    },
)
